'use strict';

exports.__esModule = true;
exports.client = exports.lock = exports.authIsRequired = exports.setAuth0User = undefined;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

exports.refreshUser = refreshUser;

var _auth0Lock = require('auth0-lock');

var _auth0Lock2 = _interopRequireDefault(_auth0Lock);

var _auth0Js = require('auth0-js');

var _auth0Js2 = _interopRequireDefault(_auth0Js);

var _react = require('react');

var _reactRedux = require('react-redux');

var _reactRouterRedux = require('react-router-redux');

var _reduxActions = require('redux-actions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _process$env = process.env,
    AUTH0_CLIENT_ID = _process$env.AUTH0_CLIENT_ID,
    AUTH0_DOMAIN = _process$env.AUTH0_DOMAIN;

var localStorage = window.localStorage;

var setAuth0User = exports.setAuth0User = (0, _reduxActions.createAction)('set auth0 user');
var authIsRequired = exports.authIsRequired = AUTH0_CLIENT_ID && AUTH0_DOMAIN;
var lock = exports.lock = authIsRequired ? new _auth0Lock2.default(AUTH0_CLIENT_ID, AUTH0_DOMAIN, {
  auth: {
    params: {
      scope: 'openid analyst offline_access'
    },
    redirect: false
  },
  closeable: false,
  autoclose: true
}) : null;
var client = exports.client = authIsRequired ? new _auth0Js2.default({
  clientID: AUTH0_CLIENT_ID,
  domain: AUTH0_DOMAIN
}) : null;

/**
 * Use on application mount when authentication is required
 */
function refreshUser(dispatch) {
  if (authIsRequired) {
    (function () {
      var userString = localStorage.getItem('user');
      var user = userString && JSON.parse(userString);
      if (user && user.refreshToken) {
        dispatch(setAuth0User(user));
        if (process.env.NODE_ENV !== 'development') {
          client.refreshToken(user.refreshToken, function (err, delegationResult) {
            if (err) {
              dispatch(setAuth0User(null));
              localStorage.setItem('user', null);
              dispatch((0, _reactRouterRedux.push)('/login'));
            } else {
              user.idToken = delegationResult.id_token;
              dispatch(setAuth0User(user));
              localStorage.setItem('user', (0, _stringify2.default)(user));
            }
          });
        }
      } else {
        dispatch((0, _reactRouterRedux.push)('/login'));
      }
    })();
  }
}

var Auth0 = function (_Component) {
  (0, _inherits3.default)(Auth0, _Component);

  function Auth0() {
    var _temp, _this, _ret2;

    (0, _classCallCheck3.default)(this, Auth0);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret2 = (_temp = (_this = (0, _possibleConstructorReturn3.default)(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this._authenticated = function (authResult) {
      var _this$props = _this.props,
          push = _this$props.push,
          setAuth0User = _this$props.setAuth0User;

      lock.getProfile(authResult.idToken, function (error, profile) {
        if (error) {
          setAuth0User(null);
          push('/login');
        } else {
          var user = (0, _extends3.default)({}, authResult, {
            profile: profile
          });
          localStorage.setItem('user', (0, _stringify2.default)(user));
          setAuth0User(user);
          push('/');
        }
      });
    }, _temp), (0, _possibleConstructorReturn3.default)(_this, _ret2);
  }

  Auth0.prototype.componentDidMount = function componentDidMount() {
    // when testing, auth0 credentials are not currently entered, so `lock` will be null
    if (lock) {
      lock.show();
      lock.on('authenticated', this._authenticated);
    }
  };

  Auth0.prototype.render = function render() {
    return null;
  };

  return Auth0;
}(_react.Component);

Auth0.propTypes = {
  push: _react.PropTypes.func.isRequired,
  setAuth0User: _react.PropTypes.func.isRequired
};


function mapStateToProps(state) {
  return state;
}
var mapDispatchToProps = {
  push: _reactRouterRedux.push,
  setAuth0User: setAuth0User
};

exports.default = (0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps)(Auth0);
//# sourceMappingURL=auth0.js